@@ -1,11 +1,14 @@
 .onLoad <- function(libname, pkgname) {
   op <- options()
+
   teal_reporter_default_options <- list(
     teal.reporter.global_knitr = list(
       echo = TRUE,
       tidy.opts = list(width.cutoff = 60),
       tidy = requireNamespace("formatR", quietly = TRUE)
     ),
+    teal.reporter.devices.dev.width = 800,
+    teal.reporter.devices.dev.height = 600,
     teal.reporter.rmd_output = c(
       "html" = "html_document", "pdf" = "pdf_document",
       "powerpoint" = "powerpoint_presentation",
@@ -15,12 +18,18 @@
       author = "NEST", title = "Report",
       date = as.character(Sys.Date()), output = "html_document",
       toc = FALSE
-    )
+    ),
+    teal.reporter.max_request_size = 10 * 1024^2
   )
 
   toset <- !(names(teal_reporter_default_options) %in% names(op))
   if (any(toset)) options(teal_reporter_default_options[toset])
 
+  # Manual import instead of using backports and adding 1 more dependency
+  if (getRversion() < "4.4") {
+    assign("%||%", rlang::`%||%`, envir = getNamespace(pkgname))
+  }
+
   invisible()
 }
 
